@@ -5,6 +5,7 @@ Examples of using the typed custom applications API
 
 import logging
 
+from examples.utils import pretty_print
 from kentik_api import CustomApplication, KentikAPI
 from kentik_api.utils import get_credentials
 
@@ -12,19 +13,6 @@ logging.basicConfig(level=logging.INFO)
 
 
 def run_crud():
-    """
-    Expected response is like:
-
-    ### CREATE
-    {'name': 'apitest-customapp-1', 'description': 'Testing custom application api', 'ip_range': '192.168.0.1,192.168.0.2', 'protocol': '6,17', 'port': '9001,9002,9003', 'asn': 'asn1,asn2,asn3', '_id': 211, '_company_id': '74333', '_user_id': '144319', '_cdate': None, '_edate': None}
-
-    ### UPDATE
-    {'name': 'apitest-customapp-ONE', 'description': 'Updated description', 'ip_range': '192.168.0.1,192.168.0.2', 'protocol': '6,17', 'port': '1023', 'asn': 'asn1,asn2,asn3', '_id': 211, '_company_id': '74333', '_user_id': '144319', '_cdate': '2020-12-11T12:10:12.853Z', '_edate': '2020-12-11T12:10:12.853Z'}
-
-    ### DELETE
-    True
-    """
-
     email, token = get_credentials()
     client = KentikAPI(email, token)
 
@@ -38,7 +26,7 @@ def run_crud():
         asn="asn1,asn2,asn3",
     )
     created = client.custom_applications.create(app)
-    print(created.__dict__)
+    pretty_print(created)
     print()
 
     print("### UPDATE")
@@ -46,7 +34,7 @@ def run_crud():
     created.description = "Updated description"
     created.port = "1023"
     updated = client.custom_applications.update(created)
-    print(updated.__dict__)
+    pretty_print(updated)
     print()
 
     # GET for single custom application item is not available in custom applications api
@@ -55,16 +43,18 @@ def run_crud():
     print("### DELETE")
     deleted = client.custom_applications.delete(updated.id)
     print(deleted)
+    print()
 
 
 def run_list():
+    print("### GET ALL")
     email, token = get_credentials()
     client = KentikAPI(email, token)
     apps = client.custom_applications.get_all()
-    for a in apps:
-        print(a.__dict__)
+    pretty_print(apps)
+    print()
 
 
 if __name__ == "__main__":
     run_crud()
-    # run_list()
+    run_list()
